@@ -16,14 +16,14 @@ class ScpiDevice(object):
     def __init__(self, resource: ScpiResource, **kwargs) -> None:
         self.resource = resource
         self.transport = resource.transport(resource.address, **kwargs)
-        logger.info(f'open [{resource.transport.transport_name}]: {resource.address}')
+        logger.info(f'open [{resource.transport._transport_class}]: {resource.address}')
 
     def is_open(self):
         return True if self.transport is not None else False
 
     def close(self) -> None:
         if self.transport is not None:
-            logger.info(f'close [{self.resource.transport.transport_name}]: {self.resource.address}')
+            logger.info(f'close [{self.resource.transport._transport_class}]: {self.resource.address}')
             self.transport.close()
             self.transport = None
 
